@@ -2,14 +2,15 @@
 
 extern crate rustc_interface;
 
-use clap::clap_app;
-use rand::prelude::*;
 use std::{
   env,
   path::PathBuf,
   process::{exit, Command},
 };
 
+use clap::clap_app;
+use rand::prelude::*;
+
 const VERSION: &str = env!("CARGO_PKG_VERSION");
 
 fn main() {
@@ -38,14 +39,29 @@ fn main() {
       (@arg end:)
       (@arg flags: ...)
     )
+    (@subcommand find_mutations =>
+      (@arg file:)
+      (@arg start:)
+      (@arg end:)
+      (@arg flags: ...)
+    )
     (@subcommand effects =>
       (@arg file:)
       (@arg pos:)
       (@arg flags: ...)
     )
-    (@subcommand graph =>
+    (@subcommand decompose =>
       (@arg file:)
       (@arg pos:)
+      (@arg flags: ...))
+    (@subcommand focus =>
+      (@arg file:)
+      (@arg pos:)
+      (@arg flags: ...))
+    (@subcommand playground =>
+      (@arg file:)
+      (@arg start:)
+      (@arg end:)
       (@arg flags: ...)
     )
   )
@@ -54,10 +70,10 @@ fn main() {
   let (mut args, file_name) = match matches.subcommand() {
     ("rustc_version", _) => {
       let commit_hash = rustc_interface::util::commit_hash_str().unwrap_or("unknown");
-      println!("{}", commit_hash);
+      println!("{commit_hash}");
       exit(0);
     }
-    ("backward_slice" | "forward_slice", Some(sub_m)) => (
+    ("backward_slice" | "forward_slice" | "playground", Some(sub_m)) => (
       vec![
         ("FILE", sub_m.value_of("file").unwrap()),
         ("START", sub_m.value_of("start").unwrap()),
@@ -79,7 +95,15 @@ fn main() {
       ],
       sub_m.value_of("file").unwrap(),
     ),
-    ("effects" | "graph", Some(sub_m)) => (
+    ("find_mutations", Some(sub_m)) => (
+      vec![
+        ("FILE", sub_m.value_of("file").unwrap()),
+        ("START", sub_m.value_of("start").unwrap()),
+        ("END", sub_m.value_of("end").unwrap()),
+      ],
+      sub_m.value_of("file").unwrap(),
+    ),
+    ("effects" | "decompose" | "focus", Some(sub_m)) => (
       vec![
         ("FILE", sub_m.value_of("file").unwrap()),
         ("POS", sub_m.value_of("pos").unwrap()),
@@ -122,7 +146,7 @@ fn main() {
       target.map(move |target| (pkg, target))
     })
     .next()
-    .unwrap_or_else(|| panic!("Could not find target for path: {}", file_name));
+    .unwrap_or_else(|| panic!("Could not find target for path: {file_name}"));
 
   let mut cmd = Command::new(cargo_path);
   cmd
@@ -133,7 +157,7 @@ fn main() {
   cmd.arg("-p").arg(&pkg.name);
   let kind = &target.kind[0];
   if kind != "proc-macro" {
-    cmd.arg(format!("--{}", kind));
+    cmd.arg(format!("--{kind}"));
   }
   match kind.as_str() {
     "lib" | "proc-macro" => {}
@@ -144,12 +168,12 @@ fn main() {
 
   // RNG is necessary to avoid caching
   let n = thread_rng().gen::<u64>();
-  cmd.args(&["--", &format!("--flowistry={}", n)]).args(flags);
+  cmd.args(&["--", &format!("--flowistry={n}")]).args(flags);
 
   // FIXME(wcrichto): we should make these CLI args as well, then do
   //   caching on VSCode's side
   for (k, v) in args {
-    cmd.env(format!("FLOWISTRY_{}", k), v);
+    cmd.env(format!("FLOWISTRY_{k}"), v);
   }
 
   let exit_status = cmd.status().expect("could not run cargo");
